MethodChannelFileSaverPlus class

An implementation of FileSaverPlusPlatform that uses method channels.

Inheritance

Properties

batteryPercentage Future<int?>
Returns the current battery percentage (0–100).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
platformVersion Future<String?>
Returns the current platform version.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveMultipleFiles({required List<Uint8List> dataList, required List<String> fileNameList, required List<String> mimeTypeList}) Future<List<String>>
Saves multiple files using platform-specific implementation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited